Welcome to Djangosaml2’s Documentation — djangosaml2 0.2.4 documentation

# Welcome to Djangosaml2’s Documentation

A Django application that builds a fully compliant SAML2 Service Provider on top of PySAML2 library. Djangosaml2 protects your project with a SAML2 SSO Authentication, supporting features like HTTP-REDIRECT and HTTP-POST SSO Binding, Single logout, Discovery Service, Wayf page with customizable html template, IdP Hinting and Samesite cookie SSO workaround.

The entire project code is open sourced and therefore licensed under the Apache 2.0.

Setup

- Setup
  - Prepare Environment and Install Requirements
  - Configuration
  - SameSite cookie
  - Authentication backend
  - Default Login path
  - Handling Post-Login Redirects
  - Preferred sso binding
  - Preferred Logout binding
  - Ignore Logout errors
  - Signed Logout Request
  - Discovery Service
  - Idp hinting
  - Custom and dynamic configuration loading
- Users, attributes and account linking
- URLs
- PySAML2 specific files and configuration

Usage

- Getting Started
- Test IdP

Developer's

- Testing
- Unit tests
- Code Coverage
- Custom error handler
- Contributing

Miscellanea

- SimpleSAMLphp issues
- Okta federation

FAQ

- FAQ